function [P, P_f, Pub_f] = WaveBot_fbPow(Zi, Fe, C, Kt, R, N)
% [P, Omega] = WaveBot_fbPow(Zi, Fe, C, Kt, R, gear_ratio)
% 
% Calculates average power for the WaveBot based on a feedback controller.
%
% Inputs
%
%   Zi      impedance FRF
%   Fe      excitation FRF
%   C       controller FRF
%   Kt      torque constant [Nm/A]
%   R       winding resistance [Ohms]
%   N       gear ratio
%
%--------------------------------------------------------------------------

% electrical constant for three-phase PMS motor
Ke = Kt*2/3;

Omega = Fe ./ (Zi - C);
P_f =  3/4*real(conj((Ke*N + C*R/(N*Kt)).*Omega) .* C/(N*Kt) .* Omega);

P = sum(P_f);

% upper-bound based on "complex conjugate control" 
% (perfect impedance matching)
Pub_f = -1 * abs(Fe).^2 ./ (8 * real(Zi));
